==> generallibrary-2.9.5.tar.gz: generallibrary-2.9.5/generallibrary/__init__.py <==

# from generallibrary.analyze import bayesian
from generallibrary.iterables import SortedList, get_values, is_iterable, depth, iter_first_value, iter_first_value, join_with_str, extend_list_in_dict, update_dict_in_dict, get_free_index, get_rows, exclusive, inclusive, unique_obj_in_list, combine, remove_duplicates, get_index, get, get_items, split_list, pivot_list, remove, flatten, subtract_list, dict_insert
from generallibrary.object import getsize
from generallibrary.text import comma_and_and, comma_and_or, plur_sing, replace, match
from generallibrary.time import Timer, sleep, Date
from generallibrary.types import strToDynamicType, typeChecker, getBaseClasses, getBaseClassNames, hasMethod, HierarchyStorer
from generallibrary.functions import calculate, defaults, EmptyContext, classproperty, CallTable, initBases, AutoInitBases, Recycle, import_module, terminal, auto_deco
from generallibrary.decorators import deco_optional_suppress, deco_cache, deco_cast_parameters, deco_bound_defaults, deco_extend, deco_propagate_while, Operators, wrapper_transfer, SigInfo, deco_require
from generallibrary.values import BoolStr, floor, ceil, round_, clamp, sign, inrange, rectify, doubleRectify, confineTo, EnvVar, get_launch_options
from generallibrary.diagram import TreeDiagram, Markdown, NetworkDiagram, Storable
from generallibrary.code import debug, CodeLine, clipboard_copy, clipboard_get, print_link, print_link_to_obj, get_definition_line, get_origin, Log
from generallibrary.versions import VerInfo, get_installed_packages, package_is_installed, PythonVersion, Ver
from generallibrary.objinfo.objinfo import ObjInfo, hook, cache_clear, call_base_hooks, DataClass, get_attrs_from_bases, dir_appearance_order
from generallibrary.serialize import dumps, loads

==> generallibrary-2.9.8.tar.gz: generallibrary-2.9.8/generallibrary/__init__.py <==

from generalimport import *

GeneralImporter("pandas")

# from generallibrary.analyze import bayesian
from generallibrary.iterables import SortedList, get_values, is_iterable, depth, iter_first_value, iter_first_value, join_with_str, extend_list_in_dict, update_dict_in_dict, get_free_index, get_rows, exclusive, inclusive, unique_obj_in_list, combine, remove_duplicates, get_index, get, get_items, split_list, pivot_list, remove, flatten, subtract_list, dict_insert
from generallibrary.object import getsize, interconnect
from generallibrary.text import comma_and_and, comma_and_or, plur_sing, replace, match
from generallibrary.time import Timer, sleep, Date
from generallibrary.types import strToDynamicType, typeChecker, getBaseClasses, getBaseClassNames, hasMethod, HierarchyStorer
from generallibrary.functions import CallTable, calculate, defaults, EmptyContext, classproperty, initBases, AutoInitBases, Recycle, \
    terminal, auto_deco
from generallibrary.decorators import deco_optional_suppress, deco_cache, deco_cast_parameters, deco_bound_defaults, deco_extend, deco_propagate_while, Operators, wrapper_transfer, SigInfo, deco_require
from generallibrary.values import BoolStr, floor, ceil, round_, clamp, sign, inrange, rectify, doubleRectify, confineTo, EnvVar, get_launch_options
from generallibrary.diagram import TreeDiagram, Markdown, NetworkDiagram, Storable
from generallibrary.code import debug, CodeLine, clipboard_copy, clipboard_get, print_link, print_link_to_obj, get_definition_line, get_origin, Log
from generallibrary.versions import VerInfo, PythonVersion, Ver
from generallibrary.objinfo.objinfo import ObjInfo, hook, cache_clear, call_base_hooks, DataClass, get_attrs_from_bases, dir_appearance_order
from generallibrary.serialize import dumps, loads
from generallibrary.context import DecoContext, RedirectStdout
